Enum ClientError
#[non_exhaustive]pub enum ClientError {
InvalidState,
PacketIdExhausted,
QuotaExhausted,
QoSNotSupported,
InvalidQoS,
PayloadTooLarge,
RetainNotAvailable,
WildcardSubNotAvailable,
SubIdNotAvailable,
SharedSubNotAvailable,
}Expand description
Errors from the client state machine.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidState
Operation not valid in the current connection state.
PacketIdExhausted
No more packet identifiers available (all 65 535 in use).
QuotaExhausted
Send quota exhausted (Receive Maximum reached).
QoSNotSupported
QoS level exceeds the server’s Maximum QoS capability.
InvalidQoS
QoS 0 was passed to a store path that only tracks QoS 1 or 2
publishes (the outbox). A QoS 0 publish is fire-and-forget and must
be sent directly rather than stored.
PayloadTooLarge
The publish payload is larger than can be encoded in a single MQTT packet (the Remaining Length VBI maximum, ~256 MiB).
RetainNotAvailable
Server declared Retain Available = false.
WildcardSubNotAvailable
Server declared Wildcard Subscription Available = false.
SubIdNotAvailable
Server declared Subscription Identifiers Available = false.
Server declared Shared Subscription Available = false.